scxpand.linear
==============

.. automodule:: scxpand.linear

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   linear_params
   linear_trainer
   model_manager
   sklearn_utils
